@@ -7,7 +7,7 @@ use LWP::UserAgent;
 use Encode;
 
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 
 my %lang_pairs = (
@@ -70,7 +70,7 @@ sub new {
         $this{unknown} = ();
     }
     
-    $this{agent} = LWP::UserAgent->new;();
+    $this{agent} = LWP::UserAgent->new();
     $this{agent}->parse_head(0);
     $this{agent}->env_proxy();
     $this{url} = 'http://xixona.dlsi.ua.es/apertium/tradtextjs.php';
@@ -99,11 +99,13 @@ sub translate {
     my $marked;
     $marked = 1 if $self->{output} eq 'marked_text';
     
+    my $source_lang = substr($self->{lang_pair}, 0, 2);
+    my $target_lang = substr($self->{lang_pair}, 3, 2);
     
     my $response = $browser->post(
                                     $self->{url},
                                     [
-                                     'cuadrotexto' => encode('utf8',$string),
+                                     'cuadrotexto' => encode('utf8', $string),
                                      'direccion' => $self->{lang_pair},
                                      'marcar' => $marked,
                                     ],
@@ -121,23 +123,19 @@ sub translate {
         return '';
     }
     
-    my $translated = $response->{'_content'};
-    
-    
-    # remove double spaces
-    $translated =~ s/(?<=\S)\s{2}(?=\S)/ /g;
+    my $translated = _fix_translated($response->{'_content'});
     
     if ($self->{output} eq 'marked_text') {
+        
         # clean HTML tags of unknown words
         $translated =~ s/<span .+?><a href.+?>(\*.+?)<\/a><\/span>/$1/g;
         
         if ($self->{store_unknown}) {
+            
+            $translated = decode_utf8($translated);
+            
             # store unknown words
             if ($translated =~ /(?:^|\W)\*/) {
-            
-                my $source_lang = substr($self->{lang_pair}, 0, 2);
-                
-                $translated = decode_utf8($translated);
                 
                 while ($translated =~ /(?:^|\W)\*(\w+?)\b/g) {
                     $self->{unknown}->{$source_lang}->{$1}++;
@@ -210,6 +208,15 @@ sub _fix_source {
     return $string;
 }
 
+sub _fix_translated {
+    my ($string) = @_;
+    
+    # remove double spaces
+    $string =~ s/(?<=\S)\s{2}(?=\S)/ /g;
+    
+    return $string;
+}
+
 
 1;
 
@@ -223,7 +230,7 @@ WWW::Translate::Apertium - Open source machine translation
 
 =head1 VERSION
 
-Version 0.04 September 30, 2007
+Version 0.05 September 30, 2007
 
 
 =head1 SYNOPSIS
@@ -421,6 +428,11 @@ Apertium engine object:
 =head2 $engine->translate($string)
 
 Returns the translation of $string generated by Apertium, encoded as utf-8.
+$string must be a string of ANSI text. If the source text isn't encoded as
+Latin-1, you must convert it to that encoding before sending it to the machine
+translation engine. For this task you can use the Encode module or the PerlIO
+layer, if you are reading the text from a file.
+
 In case the server is down, it will show a warning and return C<undef>.
 
 
